@@ -7,7 +7,6 @@
 # in practice.
 
 import numpy as np
-from sklearn.cluster import AgglomerativeClustering
 from numpy import linalg as LA
 
 #================================================================================#
@@ -148,7 +147,7 @@ def GaussMixture(N, mu=np.array([[1,1]]), cov=np.diag([1,1]).reshape(2,2,1),
     "should be equal."
     inds = np.random.choice(list(range(m)), N, replace=True, 
                             p=np.array(prob)/sum(prob))
-    data_ps = np.zeros(N,d)
+    data_ps = np.zeros((N,d))
     for i in range(m):
         data_ps[inds == i,:] = np.random.multivariate_normal(mu[i,:], cov[:,:,i], 
                                                              size=sum(inds == i))
@@ -336,7 +335,67 @@ def vMFMixtureSamp(n, mu=np.array([[0,0,1]]), kappa=[1.0], prob=[1.0]):
     inds = np.random.choice(list(range(m)), n, replace=True, p=np.array(prob)/sum(prob))
     data_ps = np.zeros((n,d))
     for i in range(m):
-        data_ps[inds == i,:] = vMF_samp(sum(inds == i), mu=mu[i,:], kappa=kappa[i])
+        data_ps[inds == i,:] = vMFSamp(sum(inds == i), mu=mu[i,:], kappa=kappa[i])
+    return data_ps
+
+
+def vMFGaussMixture(n, q=2, D=2, mu_vMF=np.array([[0,0,1]]), kappa=[1.0], 
+                    mu_N=np.array([[1,1]]), cov=np.diag([1,1]).reshape(2,2,1), 
+                    prob=[1.0]):
+    '''
+    Randomly sampling data points from a mixture of q-dimensional von-Mises Fisher 
+    and D-dimensional Gaussian distributions (directional-linear mixture model).
+    
+    Parameters
+    -----------
+        n: int
+            The number of sampling random data points.
+            
+        q: int
+            Intrinsic data dimension of directional components.
+            
+        D: int
+            Data dimension of linear components.
+    
+        mu_vMF: a (m,q+1)-array
+            Euclidean coordinates of the m mean directions for the mixture of 
+            von-Mises Fisher densities.
+       
+        kappa: list of floats
+            The m concentration parameters for the mixture of von-Mises Fisher 
+            densities.
+            
+        mu_N: (m,D)-array
+            The means of the Gaussian mixture model with m components. 
+       
+        cov: (D,D,m)-array
+            The (D,D)-covariance matrices of the Gaussian mixture model with 
+            m components.
+       
+        prob: list of floats
+            The m mixture probabilities.
+            
+    Return
+    -------
+        data_ps: (n, q+1+D)-array
+            Euclidean coordinates of the randomly sampled points from the 
+            vMF-Gaussian mixtures.
+    '''
+    m = len(prob)   ## The number of mixtures
+    
+    assert (len(kappa) == len(prob)), "The parameters 'kappa' and 'prob' "\
+    "should be of the same length."
+    assert (cov.shape[2] == len(prob)), "'cov.shape[2]' and 'len(prob)' "\
+    "should be equal."
+    
+    inds = np.random.choice(list(range(m)), n, replace=True, 
+                            p=np.array(prob)/sum(prob))
+    data_ps = np.zeros((n,q+1+D))
+    for i in range(m):
+        data_ps[inds == i,:(q+1)] = vMFSamp(sum(inds == i), mu=mu_vMF[i,:], 
+                                             kappa=kappa[i])
+        data_ps[inds == i,(q+1):(q+1+D)] \
+            = np.random.multivariate_normal(mu_N[i,:], cov[:,:,i], size=sum(inds == i))
     return data_ps
 
 
